@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: DwmAuth.cc 10617 2020-05-02 21:18:04Z dwm $
+// @(#) $Id: DwmAuth.cc 11162 2020-09-08 06:46:41Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2016
 //  All rights reserved.
@@ -49,13 +49,13 @@ extern "C" {
 #include <cryptopp/base64.h>
 #include <cryptopp/hex.h>
 
-#include "DwmIO.hh"
+#include "DwmDescriptorIO.hh"
 #include "DwmSvnTag.hh"
 #include "DwmSysLogger.hh"
 #include "DwmAuthCountedString.hh"
 #include "DwmAuth.hh"
 
-static const Dwm::SvnTag  svntag("$DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.5/src/DwmAuth.cc 10617 $");
+static const Dwm::SvnTag  svntag("$DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.6/src/DwmAuth.cc 11162 $");
 
 //----------------------------------------------------------------------------
 //!  Maximum length of string we'll accept during authentication.  This is
@@ -96,7 +96,7 @@ namespace Dwm {
       bool  rc = false;
       if (fd >= 0) {
         uint32_t  len = s.size();
-        if (IO::Write(fd, len) > 0) {
+        if (DescriptorIO::Write(fd, len) > 0) {
           if (write(fd, s.data(), s.size()) == s.size()) {
             rc = true;
           }
@@ -113,7 +113,8 @@ namespace Dwm {
       bool  rc = false;
       if (fd >= 0) {
         uint32_t  len;
-        if ((IO::Read(fd, len) > 0) && (len < MAX_BINARY_STRING_LEN)) {
+        if ((DescriptorIO::Read(fd, len) > 0)
+            && (len < MAX_BINARY_STRING_LEN)) {
           char  buf[len];
           if (read(fd, buf, len) == len) {
             s.assign(buf, len);
@@ -155,14 +156,14 @@ namespace Dwm {
                             const string & secret)
     {
       //  Send our public key to the client.
-      if (IO::Write(fd, myKeys.Public()) <= 0) {
+      if (DescriptorIO::Write(fd, myKeys.Public()) <= 0) {
         Syslog(LOG_ERR, "Failed to send public key to client");
         return false;
       }
       //  Read the client's public key.
       PKCrypto::PublicKey  clientPubKey;
-      size_t  bytesRead = IO::Read(fd, clientPubKey);
-      if (bytesRead != IO::StreamedLength(clientPubKey)) {
+      size_t  bytesRead = DescriptorIO::Read(fd, clientPubKey);
+      if (bytesRead != DescriptorIO::StreamedLength(clientPubKey)) {
         Syslog(LOG_ERR, "Failed to read public key from client");
         return false;
       }
@@ -218,8 +219,8 @@ namespace Dwm {
       bool  rc = false;
       
       PKCrypto::PublicKey  servPubKey;
-      if (IO::Read(fd, servPubKey) > 0) {
-        if (IO::Write(fd, myKeys.Public()) > 0) {
+      if (DescriptorIO::Read(fd, servPubKey) > 0) {
+        if (DescriptorIO::Write(fd, myKeys.Public()) > 0) {
           //  Read IV from server so we can decrypt challenge
           CountedString  iv;
           if (iv.Read(fd) > 0) {
