@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.5/src/DwmAuthCountedString.cc 8596 $
-// @(#) $Id: DwmAuthCountedString.cc 8596 2016-05-28 17:29:13Z dwm $
+// @(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.6/src/DwmAuthCountedString.cc 11162 $
+// @(#) $Id: DwmAuthCountedString.cc 11162 2020-09-08 06:46:41Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2016
 //  All rights reserved.
@@ -46,10 +46,12 @@ extern "C" {
 #include <cstdlib>
 
 #include "DwmSvnTag.hh"
-#include "DwmIO.hh"
+#include "DwmDescriptorIO.hh"
+#include "DwmFileIO.hh"
+#include "DwmStreamIO.hh"
 #include "DwmAuthCountedString.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.5/src/DwmAuthCountedString.cc 8596 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.6/src/DwmAuthCountedString.cc 11162 $");
 
 using namespace std;
 
@@ -65,7 +67,7 @@ namespace Dwm {
       _s.clear();
       if (is) {
         uint32_t  len;
-        if (IO::Read(is, len)) {
+        if (StreamIO::Read(is, len)) {
           char  *buf = (char *)calloc(1, len);
           if (buf) {
             is.read(buf, len);
@@ -84,7 +86,7 @@ namespace Dwm {
     {
       if (os) {
         uint32_t  len = _s.size();
-        if (IO::Write(os, len)) {
+        if (StreamIO::Write(os, len)) {
           os.write((const char *)_s.data(), len);
         }
       }
@@ -100,7 +102,7 @@ namespace Dwm {
       ssize_t  rc = -1;
       if (fd >= 0) {
         uint32_t len;
-        ssize_t  bytesRead = IO::Read(fd, len);
+        ssize_t  bytesRead = DescriptorIO::Read(fd, len);
         if (bytesRead == sizeof(len)) {
           rc = bytesRead;
           char  *buf = (char *)calloc(1, len);
@@ -131,7 +133,7 @@ namespace Dwm {
       ssize_t  rc = -1;
       if (fd >= 0) {
         uint32_t  len = _s.size();
-        ssize_t  bytesWritten = IO::Write(fd, len);
+        ssize_t  bytesWritten = DescriptorIO::Write(fd, len);
         if (bytesWritten == sizeof(len)) {
           rc = bytesWritten;
           bytesWritten = write(fd, _s.data(), len);
@@ -155,7 +157,7 @@ namespace Dwm {
       size_t  rc = 0;
       if (f) {
         uint32_t  len;
-        if (IO::Read(f, len)) {
+        if (FileIO::Read(f, len)) {
           char  *buf = (char *)calloc(1, len);
           if (buf) {
             if (fread(buf, len, 1, f) == 1) {
@@ -177,7 +179,7 @@ namespace Dwm {
       size_t  rc = 0;
       if (f) {
         uint32_t  len = _s.size();
-        if (IO::Write(f, len)) {
+        if (FileIO::Write(f, len)) {
           if (fwrite(_s.data(), len, 1, f) == 1) {
             rc = 1;
           }
