@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.5/src/DwmAuthEd25519Keys.cc 10666 $
-// @(#) $Id: DwmAuthEd25519Keys.cc 10666 2020-05-03 18:50:48Z dwm $
+// @(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.6/src/DwmAuthEd25519Keys.cc 11162 $
+// @(#) $Id: DwmAuthEd25519Keys.cc 11162 2020-09-08 06:46:41Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2018, 2020
 //  All rights reserved.
@@ -49,7 +49,9 @@ extern "C" {
 #include <cryptopp/base64.h>
 
 #include "DwmSysLogger.hh"
-#include "DwmIO.hh"
+#include "DwmDescriptorIO.hh"
+#include "DwmFileIO.hh"
+#include "DwmStreamIO.hh"
 #include "DwmAuthEd25519Keys.hh"
 
 using namespace std;
@@ -74,7 +76,7 @@ namespace Dwm {
     {
       if (is) {
         uint16_t  len;
-        if (IO::Read(is, len)) {
+        if (StreamIO::Read(is, len)) {
           char  *buf = (char *)calloc(1, len);
           if (buf) {
             if (is.read(buf, len)) {
@@ -109,7 +111,7 @@ namespace Dwm {
       if (os) {
         string  s = ToString();
         uint16_t  len = s.size();
-        if (IO::Write(os, len)) {
+        if (StreamIO::Write(os, len)) {
           os.write(s.data(), len);
         }
       }
@@ -124,7 +126,7 @@ namespace Dwm {
       size_t  rc = 0;
       if (f) {
         uint16_t  len;
-        if (IO::Read(f, len)) {
+        if (FileIO::Read(f, len)) {
           char  *buf = (char *)calloc(1, len);
           if (buf) {
             if (fread(buf, len, 1, f) == 1) {
@@ -158,7 +160,7 @@ namespace Dwm {
       if (f) {
         string  s = ToString();
         uint16_t  len = s.size();
-        if (IO::Write(f, len)) {
+        if (FileIO::Write(f, len)) {
           if (len > 0) {
             rc = fwrite(s.data(), len, 1, f);
           }
@@ -178,13 +180,13 @@ namespace Dwm {
       ssize_t  rc = -1;
       if (0 <= fd) {
         uint16_t  len;
-        ssize_t  bytesRead = IO::Read(fd, len);
+        ssize_t  bytesRead = DescriptorIO::Read(fd, len);
         if (0 < bytesRead) {
           rc = bytesRead;
           if (len) {
             char  *buf = (char *)calloc(1, len);
             if (buf) {
-              if (IO::Read(fd, buf, len) == len) {
+              if (DescriptorIO::Read(fd, buf, len) == len) {
                 string  s(buf, len);
                 FromString(s);
                 rc += s.size();
@@ -216,10 +218,10 @@ namespace Dwm {
       if (0 <= fd) {
         string  s = ToString();
         uint16_t  len = s.size();
-        if (Dwm::IO::Write(fd, len)) {
+        if (Dwm::DescriptorIO::Write(fd, len)) {
           rc = sizeof(len);
           if (len > 0) {
-            ssize_t  bytesWritten = IO::Write(fd, s.data(), len);
+            ssize_t  bytesWritten = DescriptorIO::Write(fd, s.data(), len);
             if (0 < bytesWritten) {
               rc += bytesWritten;
             }
@@ -333,7 +335,7 @@ namespace Dwm {
     {
       if (is) {
         uint16_t  len;
-        if (IO::Read(is, len)) {
+        if (StreamIO::Read(is, len)) {
           char  *buf = (char *)calloc(1, len);
           if (buf) {
             if (is.read(buf, len)) {
@@ -368,7 +370,7 @@ namespace Dwm {
       if (os) {
         string  s = ToString();
         uint16_t  len = s.size();
-        if (IO::Write(os, len)) {
+        if (StreamIO::Write(os, len)) {
           os.write(s.data(), len);
         }
       }
@@ -383,7 +385,7 @@ namespace Dwm {
       size_t  rc = 0;
       if (f) {
         uint16_t  len;
-        if (IO::Read(f, len)) {
+        if (FileIO::Read(f, len)) {
           char  *buf = (char *)calloc(1, len);
           if (buf) {
             if (fread(buf, len, 1, f) == 1) {
@@ -417,7 +419,7 @@ namespace Dwm {
       if (f) {
         string  s = ToString();
         uint16_t  len = s.size();
-        if (Dwm::IO::Write(f, len)) {
+        if (Dwm::FileIO::Write(f, len)) {
           if (len > 0) {
             rc = fwrite(s.data(), len, 1, f);
           }
@@ -437,13 +439,13 @@ namespace Dwm {
       ssize_t  rc = -1;
       if (0 <= fd) {
         uint16_t  len;
-        ssize_t  bytesRead = IO::Read(fd, len);
+        ssize_t  bytesRead = DescriptorIO::Read(fd, len);
         if (0 < bytesRead) {
           rc = bytesRead;
           if (len) {
             char  *buf = (char *)calloc(1, len);
             if (buf) {
-              if (IO::Read(fd, buf, len) == len) {
+              if (DescriptorIO::Read(fd, buf, len) == len) {
                 string  s(buf, len);
                 FromString(s);
                 rc += s.size();
@@ -475,7 +477,7 @@ namespace Dwm {
       if (0 <= fd) {
         string  s = ToString();
         uint16_t  len = s.size();
-        if (Dwm::IO::Write(fd, len)) {
+        if (Dwm::DescriptorIO::Write(fd, len)) {
           rc = sizeof(len);
           if (len > 0) {
             ssize_t  bytesWritten = write(fd, s.data(), len);
