@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.5/src/DwmAuthPKCrypto.cc 9849 $
-// @(#) $Id: DwmAuthPKCrypto.cc 9849 2017-12-18 23:28:41Z dwm $
+// @(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.6/src/DwmAuthPKCrypto.cc 11162 $
+// @(#) $Id: DwmAuthPKCrypto.cc 11162 2020-09-08 06:46:41Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2016
 //  All rights reserved.
@@ -49,12 +49,14 @@ extern "C" {
 #include <regex>
 #include <cryptopp/base64.h>
 
-#include "DwmIO.hh"
+#include "DwmDescriptorIO.hh"
+#include "DwmFileIO.hh"
+#include "DwmStreamIO.hh"
 #include "DwmSvnTag.hh"
 #include "DwmSysLogger.hh"
 #include "DwmAuthPKCrypto.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.5/src/DwmAuthPKCrypto.cc 9849 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.6/src/DwmAuthPKCrypto.cc 11162 $");
 
 using namespace std;
 using CryptoPP::Base64Decoder;
@@ -81,7 +83,7 @@ namespace Dwm {
     {
       if (is) {
         uint16_t  len;
-        if (Dwm::IO::Read(is, len)) {
+        if (Dwm::StreamIO::Read(is, len)) {
           char  *buf = (char *)calloc(1, len);
           if (buf) {
             if (is.read(buf, len)) {
@@ -104,7 +106,7 @@ namespace Dwm {
       ssize_t  rc = -1;
       if (fd >= 0) {
         uint16_t  len;
-        ssize_t  bytesRead = Dwm::IO::Read(fd, len);
+        ssize_t  bytesRead = Dwm::DescriptorIO::Read(fd, len);
         if (bytesRead == sizeof(len)) {
           rc = bytesRead;
           char  *buf = (char *)calloc(1, len);
@@ -136,7 +138,7 @@ namespace Dwm {
       size_t  rc = 0;
       if (f) {
         uint16_t  len;
-        if (Dwm::IO::Read(f, len) == sizeof(len)) {
+        if (Dwm::FileIO::Read(f, len) == sizeof(len)) {
           if (len > 0) {
             rc = sizeof(len);
             char  *buf = (char *)calloc(1, len);
@@ -166,7 +168,7 @@ namespace Dwm {
       if (os) {
         string  s = ToString();
         uint16_t  len = s.size();
-        if (Dwm::IO::Write(os, len)) {
+        if (Dwm::StreamIO::Write(os, len)) {
           os.write(s.data(), len);
         }
       }
@@ -182,7 +184,7 @@ namespace Dwm {
       if (fd >= 0) {
         string  s = ToString();
         uint16_t  len = s.size();
-        if (Dwm::IO::Write(fd, len) == sizeof(len)) {
+        if (Dwm::DescriptorIO::Write(fd, len) == sizeof(len)) {
           rc = sizeof(len);
           ssize_t  bytesWritten = write(fd, s.data(), len);
           if (bytesWritten == len) {
@@ -205,7 +207,7 @@ namespace Dwm {
       if (f) {
         string s = ToString();
         uint16_t  len = s.size();
-        if (Dwm::IO::Write(f, len) == sizeof(len)) {
+        if (Dwm::FileIO::Write(f, len) == sizeof(len)) {
           rc = sizeof(len);
           if (fwrite((void *)s.data(), len, 1, f) == 1) {
             rc += len;
@@ -309,7 +311,7 @@ namespace Dwm {
     {
       if (is) {
         uint16_t  len;
-        if (Dwm::IO::Read(is, len)) {
+        if (Dwm::StreamIO::Read(is, len)) {
           char  *buf = (char *)calloc(1, len);
           if (buf) {
             if (is.read(buf, len)) {
@@ -332,7 +334,7 @@ namespace Dwm {
       ssize_t  rc = -1;
       if (fd >= 0) {
         uint16_t  len;
-        ssize_t  bytesRead = Dwm::IO::Read(fd, len);
+        ssize_t  bytesRead = Dwm::DescriptorIO::Read(fd, len);
         if (bytesRead == sizeof(len)) {
           rc = bytesRead;
           char  *buf = (char *)calloc(1, len);
@@ -364,7 +366,7 @@ namespace Dwm {
       size_t  rc = 0;
       if (f) {
         uint16_t  len;
-        if (Dwm::IO::Read(f, len) == sizeof(len)) {
+        if (Dwm::FileIO::Read(f, len) == sizeof(len)) {
           if (len > 0) {
             rc = sizeof(len);
             char  *buf = (char *)calloc(1, len);
@@ -394,7 +396,7 @@ namespace Dwm {
       if (os) {
         string  s = ToString();
         uint16_t  len = s.size();
-        if (Dwm::IO::Write(os, len)) {
+        if (Dwm::StreamIO::Write(os, len)) {
           os.write(s.data(), len);
         }
       }
@@ -410,7 +412,7 @@ namespace Dwm {
       if (fd >= 0) {
         string  s = ToString();
         uint16_t  len = s.size();
-        if (Dwm::IO::Write(fd, len) == sizeof(len)) {
+        if (Dwm::DescriptorIO::Write(fd, len) == sizeof(len)) {
           rc = sizeof(len);
           ssize_t  bytesWritten = write(fd, s.data(), len);
           if (bytesWritten == len) {
@@ -433,7 +435,7 @@ namespace Dwm {
       if (f) {
         string s = ToString();
         uint16_t  len = s.size();
-        if (Dwm::IO::Write(f, len) == sizeof(len)) {
+        if (Dwm::FileIO::Write(f, len) == sizeof(len)) {
           rc = sizeof(len);
           if (fwrite((void *)s.data(), len, 1, f) == 1) {
             rc += len;
