@@ -1,6 +1,6 @@
 //===========================================================================
 // @(#) $Name:$
-// @(#) $Id: DwmAuthPeerAuthenticator.cc 10973 2020-08-25 02:48:22Z dwm $
+// @(#) $Id: DwmAuthPeerAuthenticator.cc 11162 2020-09-08 06:46:41Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2017, 2020
 //  All rights reserved.
@@ -57,14 +57,16 @@ extern "C" {
 #include <cryptopp/pssr.h>
 #include <cryptopp/secblock.h>
 
-#include "DwmIO.hh"
+#include "DwmDescriptorIO.hh"
+#include "DwmStreamIO.hh"
+#include "DwmIOUtils.hh"
 #include "DwmSvnTag.hh"
 #include "DwmSysLogger.hh"
 #include "DwmAuthPeerAuthenticator.hh"
 #include "DwmAuthSymCrypto.hh"
 #include "DwmAuthUtils.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.5/src/DwmAuthPeerAuthenticator.cc 10973 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.6/src/DwmAuthPeerAuthenticator.cc 11162 $");
 
 using namespace std;
 using CryptoPP::PSS;
@@ -150,7 +152,8 @@ namespace Dwm {
       bool  rc = false;
       if (fd >= 0) {
         string  mypubEC = to_str(agreement.Public());
-        if (IO::Write(fd, mypubEC) == IO::StreamedLength(mypubEC)) {
+        if (DescriptorIO::Write(fd, mypubEC)
+            == IOUtils::StreamedLength(mypubEC)) {
           string   theirPubECDH;
           if (Utils::WaitForBytesReady(fd, 36, chrono::milliseconds(5000))) {
             ssize_t  bytesRead =
@@ -298,8 +301,8 @@ namespace Dwm {
                       new SignerFilter(rng, signer,
                                        new StringSink(mySignature)));
       ostringstream  os;
-      IO::Write(os, myIdCrypted);
-      IO::Write(os, mySignature);
+      StreamIO::Write(os, myIdCrypted);
+      StreamIO::Write(os, mySignature);
       return os.str();
     }
 
@@ -316,7 +319,7 @@ namespace Dwm {
       bool  rc = false;
       if (fd >= 0) {
         string idAndSig = BuildIDAndSignature(agreement);
-        if (IO::Write(fd, idAndSig)) {
+        if (DescriptorIO::Write(fd, idAndSig)) {
           string  s;
           auto  endTime = chrono::system_clock::now() + chrono::milliseconds(5000);
           if (Utils::ReadLengthRestrictedString(fd, s, 2048, endTime) > 0) {
@@ -366,9 +369,9 @@ namespace Dwm {
           string  keystr((to_str(agreement.AgreedKey())).substr(0, 16));
           string  ivstr((to_str(agreement.AgreedKey())).substr(16, 16));
           istringstream  is(s);
-          if (IO::Read(is, theirIdCrypted)) {
+          if (StreamIO::Read(is, theirIdCrypted)) {
             theirId = SymCrypto::Decrypt(keystr, ivstr, theirIdCrypted);
-            if (IO::Read(is, theirSig)) {
+            if (StreamIO::Read(is, theirSig)) {
               rc = true;
             }
             else {
