@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.5/src/DwmAuthSymCryptoMessage.cc 9848 $
-// @(#) $Id: DwmAuthSymCryptoMessage.cc 9848 2017-12-18 22:25:38Z dwm $
+// @(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.6/src/DwmAuthSymCryptoMessage.cc 11162 $
+// @(#) $Id: DwmAuthSymCryptoMessage.cc 11162 2020-09-08 06:46:41Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2016
 //  All rights reserved.
@@ -47,13 +47,15 @@ extern "C" {
 #include <sstream>
 #include <cryptopp/osrng.h>
 
-#include "DwmIO.hh"
+#include "DwmDescriptorIO.hh"
+#include "DwmFileIO.hh"
+#include "DwmStreamIO.hh"
 #include "DwmSvnTag.hh"
 #include "DwmSysLogger.hh"
 #include "DwmAuthSymCrypto.hh"
 #include "DwmAuthSymCryptoMessage.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.5/src/DwmAuthSymCryptoMessage.cc 9848 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.6/src/DwmAuthSymCryptoMessage.cc 11162 $");
 
 using namespace std;
 
@@ -239,7 +241,7 @@ namespace Dwm {
       //----------------------------------------------------------------------
       ssize_t Message::ReadMsgValue(int fd)
       {
-        return IO::Read(fd, _msg);
+        return DescriptorIO::Read(fd, _msg);
       }
           
       //----------------------------------------------------------------------
@@ -247,7 +249,7 @@ namespace Dwm {
       //----------------------------------------------------------------------
       ssize_t Message::WriteMsgValue(int fd) const
       {
-        return IO::Write(fd, _msg);
+        return DescriptorIO::Write(fd, _msg);
       }
       
       //----------------------------------------------------------------------
@@ -255,7 +257,7 @@ namespace Dwm {
       //----------------------------------------------------------------------
       istream & Message::ReadMsgValue(istream & is)
       {
-        return IO::Read(is, _msg);
+        return StreamIO::Read(is, _msg);
       }
       
       //----------------------------------------------------------------------
@@ -263,7 +265,7 @@ namespace Dwm {
       //----------------------------------------------------------------------
       ostream & Message::WriteMsgValue(ostream & os) const
       {
-        return IO::Write(os, _msg);
+        return StreamIO::Write(os, _msg);
       }
       
       //----------------------------------------------------------------------
@@ -271,7 +273,7 @@ namespace Dwm {
       //----------------------------------------------------------------------
       size_t Message::ReadMsgValue(FILE *f)
       {
-        return IO::Read(f, _msg);
+        return FileIO::Read(f, _msg);
       }
       
       //----------------------------------------------------------------------
@@ -279,7 +281,7 @@ namespace Dwm {
       //----------------------------------------------------------------------
       size_t Message::WriteMsgValue(FILE *f) const
       {
-        return IO::Write(f, _msg);
+        return FileIO::Write(f, _msg);
       }
       
       //----------------------------------------------------------------------
