@@ -1,6 +1,6 @@
 //===========================================================================
-// @(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.5/src/DwmAuthUtils.cc 10973 $
-// @(#) $Id: DwmAuthUtils.cc 10973 2020-08-25 02:48:22Z dwm $
+// @(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.6/src/DwmAuthUtils.cc 11162 $
+// @(#) $Id: DwmAuthUtils.cc 11162 2020-09-08 06:46:41Z dwm $
 //===========================================================================
 //  Copyright (c) Daniel W. McRobb 2020
 //  All rights reserved.
@@ -47,12 +47,13 @@ extern "C" {
 #include <thread>
 
 #include "DwmASIO.hh"
-#include "DwmIO.hh"
+#include "DwmDescriptorIO.hh"
+#include "DwmStreamIO.hh"
 #include "DwmSvnTag.hh"
 #include "DwmSysLogger.hh"
 #include "DwmAuthUtils.hh"
 
-static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.5/src/DwmAuthUtils.cc 10973 $");
+static const Dwm::SvnTag svntag("@(#) $DwmPath: dwm/libDwmAuth/tags/libDwmAuth-0.3.6/src/DwmAuthUtils.cc 11162 $");
 
 namespace Dwm {
 
@@ -157,12 +158,12 @@ namespace Dwm {
       ssize_t  rc = -1;
       if (fd >= 0) {
         uint32_t  len;
-        if (IO::Read(fd, len) == sizeof(len)) {
+        if (DescriptorIO::Read(fd, len) == sizeof(len)) {
           if (len > 0) {
             if (len <= maxLen) {
               try {
                 s.resize(len);
-                if (IO::Read(fd, s.data(), len)) {
+                if (DescriptorIO::Read(fd, s.data(), len)) {
                   rc = sizeof(len) + len;
                 }
                 else {
@@ -251,7 +252,7 @@ namespace Dwm {
       s.clear();
       if (is) {
         uint32_t  len;
-        if (IO::Read(is, len)) {
+        if (StreamIO::Read(is, len)) {
           if (len > 0) {
             if (len <= maxLen) {
               try {
@@ -305,13 +306,13 @@ namespace Dwm {
       if (fd >= 0) {
         uint32_t  len;
         if (WaitUntilBytesReady(fd, sizeof(len), endTime)) {
-          if (IO::Read(fd, len) == sizeof(len)) {
+          if (DescriptorIO::Read(fd, len) == sizeof(len)) {
             if (len > 0) {
               if (len <= maxLen) {
                 if (WaitUntilBytesReady(fd, len, endTime)) {
                   try {
                     s.resize(len);
-                    if (IO::Read(fd, s.data(), len)) {
+                    if (DescriptorIO::Read(fd, s.data(), len)) {
                       rc = sizeof(len) + len;
                     }
                     else {
